==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/es-CO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este usuario puede iniciar sesión',
    'activated_disabled_help_text' => 'No puede editar el estado de activación de su propia cuenta.',
    'assets_user'       => 'Activos asignados a :name',
    'bulk_update_warn'	=> 'Está a punto de modificar las propiedades de :user_count usuarios. Por favor, tenga en cuenta que no puede modificar las propiedades de su propio usuario con este formulario, y debe realizar las modificaciones a su propio usuario de forma individual.',
    'bulk_update_help'	=> 'Este formulario le permite actualizar varios usuarios a la vez. Solo diligencie los campos que necesita modificar. Los campos que queden en blanco no se modificarán.',
    'current_assets'    => 'Activos actualmente asignados a este usuario',
    'clone'             => 'Clonar usuario',
    'contact_user'      => 'Contacto :name',
    'edit'              => 'Editar usuario',
    'filetype_info'     => 'Los tipos de archivo permitidos son png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, y rar.',
    'history_user'      => 'Historial de :name',
    'info'				=> 'Información',
    'restore_user'		=> 'Haga clic aquí para restaurarlos.',
    'last_login'        => 'Último acceso',
    'ldap_config_text'  => 'Los ajustes de configuración para LDAP se pueden encontrar en Administrador> LDAP. La ubicación (opcional) seleccionada se establecerá para todos los usuarios importados.',
    'print_assigned'    => 'Imprimir todos los asignados',
    'email_assigned'    => 'Enviar correo con todos los asignados',
    'user_notified'     => 'Se ha enviado al usuario un correo electrónico con lista de los elementos que tiene asignados actualmente.',
    'auto_assign_label' => 'Incluye a este usuario al asignar automáticamente licencias elegibles',
    'auto_assign_help'  => 'Omitir este usuario en la asignación automática de licencias',
    'software_user'     => 'Software asignado a :name',
    'send_email_help'   => 'Debe proporcionar una dirección de correo electrónico para este usuario para poder enviarle las credenciales. Únicamente pueden enviarse las credenciales por correo eléctronico durante la creación del usuario. Las contraseñas se almacenan en un hash de un solo sentido y no se pueden recuperar una vez guardadas.',
    'view_user'         => 'Ver usuario :name',
    'usercsv'           => 'Archivo CSV',
    'two_factor_admin_optin_help' => 'La configuración actual permite la aplicación selectiva de la autenticación de dos factores.  ',
    'two_factor_enrolled' => 'Dispositivo con 2FA inscrito ',
    'two_factor_active'   => '2FA activo ',
    'user_deactivated'  => 'El usuario no puede iniciar sesión',
    'user_activated'  => 'El usuario puede iniciar sesión',
    'activation_status_warning' => 'No cambiar el estado de activación',
    'group_memberships_helpblock' => 'Sólo los superadministradores pueden editar membresías de grupo.',
    'superadmin_permission_warning' => 'Sólo los superadministradores pueden conceder acceso a un usuario superadministrador.',
    'admin_permission_warning' => 'Sólo los usuarios con derechos de administrador o mayores pueden conceder acceso de administrador a los usuarios.',
    'remove_group_memberships' => 'Eliminar membresías de grupo',
    'warning_deletion_information' => 'Está a punto de ingresar TODOS los elementos de :count usuario(s) listados a continuación. Los nombres de usuarios con permisos Super Administrador están resaltados en rojo.',
    'update_user_assets_status' => 'Actualizar todos los activos para estos usuarios a este estado',
    'checkin_user_properties' => 'Comprobar todas las propiedades asociadas a estos usuarios',
    'remote_label'   => 'Este es un usuario remoto',
    'remote'   => 'Remoto',
    'remote_help' => 'Esto puede ser útil si necesita filtrar por usuarios remotos que nunca o raramente asisten a sus ubicaciones físicas.',
    'not_remote_label' => 'Este no es un usuario remoto',
    'vip_label' => 'Usuario VIP',
    'vip_help' => 'Esto puede ser útil como indicador de personas importantes en su organización si desea tratarlas de forma especial.',
    'create_user' => 'Crear un usuario',
    'create_user_page_explanation' => 'Esta es la información de la cuenta que usará para acceder al sitio por primera vez.',
    'email_credentials' => 'Credenciales de email',
    'email_credentials_text' => 'Enviar mis credenciales a la dirección de correo de arriba',
    'next_save_user' => 'Siguiente: Guardar usuario',
    'all_assigned_list_generation' => 'Generado el:',
    'email_user_creds_on_create' => '¿Enviar a este usuario sus credenciales?',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/es-CO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este usuario puede iniciar sesión',
    'activated_disabled_help_text' => 'No puede editar el estado de activación de su propia cuenta.',
    'assets_user'       => 'Activos asignados a :name',
    'bulk_update_warn'	=> 'Está a punto de modificar las propiedades de :user_count usuarios. Por favor, tenga en cuenta que no puede modificar las propiedades de su propio usuario con este formulario, y debe realizar las modificaciones a su propio usuario de forma individual.',
    'bulk_update_help'	=> 'Este formulario le permite actualizar varios usuarios a la vez. Solo diligencie los campos que necesita modificar. Los campos que queden en blanco no se modificarán.',
    'current_assets'    => 'Activos actualmente asignados a este usuario',
    'clone'             => 'Clonar usuario',
    'contact_user'      => 'Contacto :name',
    'edit'              => 'Editar usuario',
    'filetype_info'     => 'Los tipos de archivo permitidos son png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, y rar.',
    'history_user'      => 'Historial de :name',
    'info'				=> 'Información',
    'restore_user'		=> 'Haga clic aquí para restaurarlos.',
    'last_login'        => 'Último acceso',
    'ldap_config_text'  => 'Los ajustes de configuración para LDAP se pueden encontrar en Administrador> LDAP. La ubicación (opcional) seleccionada se establecerá para todos los usuarios importados.',
    'print_assigned'    => 'Imprimir todos los asignados',
    'email_assigned'    => 'Enviar correo con todos los asignados',
    'user_notified'     => 'Se ha enviado al usuario un correo electrónico con lista de los elementos que tiene asignados actualmente.',
    'auto_assign_label' => 'Incluye a este usuario al asignar automáticamente licencias elegibles',
    'auto_assign_help'  => 'Omitir este usuario en la asignación automática de licencias',
    'software_user'     => 'Software asignado a :name',
    'send_email_help'   => 'Debe proporcionar una dirección de correo electrónico para este usuario para poder enviarle las credenciales. Únicamente pueden enviarse las credenciales por correo eléctronico durante la creación del usuario. Las contraseñas se almacenan en un hash de un solo sentido y no se pueden recuperar una vez guardadas.',
    'view_user'         => 'Ver usuario :name',
    'usercsv'           => 'Archivo CSV',
    'two_factor_admin_optin_help' => 'La configuración actual permite la aplicación selectiva de la autenticación de dos factores.  ',
    'two_factor_enrolled' => 'Dispositivo con 2FA inscrito ',
    'two_factor_active'   => '2FA activo ',
    'user_deactivated'  => 'El usuario no puede iniciar sesión',
    'user_activated'  => 'El usuario puede iniciar sesión',
    'activation_status_warning' => 'No cambiar el estado de activación',
    'group_memberships_helpblock' => 'Sólo los superadministradores pueden editar membresías de grupo.',
    'superadmin_permission_warning' => 'Sólo los superadministradores pueden conceder acceso a un usuario superadministrador.',
    'admin_permission_warning' => 'Sólo los usuarios con derechos de administrador o mayores pueden conceder acceso de administrador a los usuarios.',
    'remove_group_memberships' => 'Eliminar membresías de grupo',
    'warning_deletion_information' => 'Está a punto de ingresar TODOS los elementos de :count usuario(s) listados a continuación. Los nombres de usuarios con permisos Super Administrador están resaltados en rojo.',
    'update_user_assets_status' => 'Actualizar todos los activos para estos usuarios a este estado',
    'checkin_user_properties' => 'Comprobar todas las propiedades asociadas a estos usuarios',
    'remote_label'   => 'Este es un usuario remoto',
    'remote'   => 'Remoto',
    'remote_help' => 'Esto puede ser útil si necesita filtrar por usuarios remotos que nunca o raramente asisten a sus ubicaciones físicas.',
    'not_remote_label' => 'Este no es un usuario remoto',
    'vip_label' => 'Usuario VIP',
    'vip_help' => 'Esto puede ser útil como indicador de personas importantes en su organización si desea tratarlas de forma especial.',
    'create_user' => 'Crear un usuario',
    'create_user_page_explanation' => 'Esta es la información de la cuenta que usará para acceder al sitio por primera vez.',
    'email_credentials' => 'Credenciales de correo electrónico',
    'email_credentials_text' => 'Enviar mis credenciales a la dirección de correo electrónico de arriba',
    'next_save_user' => 'Siguiente: Guardar usuario',
    'all_assigned_list_generation' => 'Generado el:',
    'email_user_creds_on_create' => '¿Enviar las credenciales por correo electrónico a este usuario?',
];
